@@ -4,14 +4,14 @@ import sys
 
 
 def _print_output(output):
+    if hasattr(output, 'stdout') and output.stdout:
+        print(output.stdout)
+
+    if hasattr(output, 'stderr') and output.stderr:
+        print(colored(output.stderr, "red"), file=sys.stderr)
+
     if isinstance(output, Exception):
         print(output)
-        return
-
-    if output.stdout:
-        print(output.stdout)
-    if output.stderr:
-        print(colored(output.stderr, "red"), file=sys.stderr)
 
 
 def ss(
